# Table of Contents

- [microservice-modeling-guidelines](<./microservice-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Microservice Modeling Guidelines](<./Microservice-Modeling-Guidelines.md>)
  - [Definition](<./Microservice-Modeling-Guidelines/Definition.md>)
  - [Modeling Microservices](<./Microservice-Modeling-Guidelines/Modeling-Microservices.md>)
  - [Antipattern](<./Microservice-Modeling-Guidelines/Antipattern.md>)
